@@ -2,7 +2,7 @@
 """
 @Author: ChenCheng
 @Date: 2022-03-18 10:12:12
-@LastEditTime: 2022-07-25 15:21:48
+@LastEditTime: 2022-07-25 19:25:04
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -29,8 +29,10 @@ class InitLaunchGoodsHandler(SevenBaseHandler):
         """
         app_id = self.get_param("app_id")
         act_id = int(self.get_param("act_id", 0))
+        act_info_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
+        act_name = act_info_dict["act_name"] if act_info_dict else ""
         online_url = self.get_online_url(act_id, app_id)
-        return self.reponse_json_success({"url": online_url, "act_name": "", "goods_list": []})
+        return self.reponse_json_success({"url": online_url, "act_name": act_name, "goods_list": []})
 
 
 class ResetLaunchGoodsHandler(SevenBaseHandler):
