@@ -1,4 +1,11 @@
-
+# -*- coding: utf-8 -*-
+"""
+@Author: HuangJianYi
+@Date: 2021-10-15 17:46:13
+@LastEditTime: 2022-02-16 19:11:12
+@LastEditors: HuangJianYi
+@Description: 
+"""
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
@@ -13,7 +20,7 @@ class PrizeRosterModel(BaseModel):
         self.db.context = context
 
     #方法扩展请继承此类
-    
+
 class PrizeRoster:
 
     def __init__(self):
@@ -22,6 +29,7 @@ class PrizeRoster:
         self.app_id = ""  # app_id
         self.act_id = 0  # act_id
         self.open_id = ""  # open_id
+        self.machine_type = 2  # 机台类型：1消耗积分2消耗次数3会员积分
         self.machine_id = 0  # 机台id
         self.machine_name = ""  # 机台名称
         self.machine_price = 0  # 机台价格
@@ -59,12 +67,14 @@ class PrizeRoster:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'open_id', 'machine_id', 'machine_name', 'machine_price', 'prize_type', 'prize_id', 'prize_name', 'prize_price', 'prize_pic', 'prize_detail', 'tag_id', 'award_id', 'award_name', 'user_nick', 'avatar', 'prize_code', 'order_status', 'is_sku', 'use_redrawcard_count', 'prize_order_id', 'prize_order_no', 'sku_id', 'series_id', 'properties_name', 'goods_id', 'goods_code', 'goods_code_list', 'main_pay_order_no', 'order_no', 'frequency_source', 'sku_detail', 'right_ename', 'remark', 'create_date', 'toys_pic']
-        
+        return [
+            'id', 'app_id', 'act_id', 'open_id', 'machine_type', 'machine_id', 'machine_name', 'machine_price', 'prize_type', 'prize_id', 'prize_name', 'prize_price', 'prize_pic', 'prize_detail', 'tag_id', 'award_id', 'award_name', 'user_nick', 'avatar', 'prize_code', 'order_status', 'is_sku', 'use_redrawcard_count', 'prize_order_id', 'prize_order_no', 'sku_id', 'series_id', 'properties_name', 'goods_id', 'goods_code', 'goods_code_list', 'main_pay_order_no', 'order_no', 'frequency_source',
+            'sku_detail', 'right_ename', 'remark', 'create_date', 'toys_pic'
+        ]
+
     @classmethod
     def get_primary_key(self):
         return "id"
 
     def __str__(self):
         return "prize_roster_tb"
-    
\ No newline at end of file
